Enum esexpr::ESExprTag

source ·
pub enum ESExprTag {
    Constructor(String),
    Bool,
    Int,
    Str,
    Binary,
    Float32,
    Float64,
    Null,
}
An expression tag.

Variants



Constructor(String)

A tag for a constructor with a specified name.



Bool

A tag for a bool value.



Int

A tag for a int value.



Str

A tag for a str value.



Binary

A tag for a binary value.



Float32

A tag for a float32 value.



Float64

A tag for a float64 value.



Null

A tag for a null value.

Implementations

source

impl ESExprTag

source

pub fn is_constructor(&self, s: &str) -> bool

Checks whether the tag is for a constructor value.